==> AxolotlClient-3.1.6%2B1.21.10-sources.jar: io/github/axolotlclient/util/options/rounded/ForceableBooleanWidget.java <==
/*
 * Copyright © 2024 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.util.options.rounded;

import io.github.axolotlclient.AxolotlClientConfig.impl.ui.rounded.widgets.PillBooleanWidget;
import io.github.axolotlclient.util.options.ForceableBooleanOption;
import net.minecraft.class_11907;
import net.minecraft.class_332;

public class ForceableBooleanWidget extends PillBooleanWidget {
	private final ForceableBooleanOption option;

	public ForceableBooleanWidget(int x, int y, int width, int height, ForceableBooleanOption option) {
		super(x, y, width, height, option);
		this.option = option;
	}

	@Override
	public void method_48579(class_332 graphics, int mouseX, int mouseY, float delta) {
		this.field_22763 = !option.isForceOff();
		super.method_48579(graphics, mouseX, mouseY, delta);
	}

	@Override
	protected void drawHandle(long ctx, float x, float y, float width) {
		if (option.isForceOff()) {
			super.drawHandle(ctx, method_46426() + OFF_POSITION, y, width);
		} else {
			super.drawHandle(ctx, x, y, width);
		}
	}

	@Override
	public void method_25306(class_11907 mods) {
		if (!option.isForceOff()) {
			super.method_25306(mods);
		}
	}
}

==> AxolotlClient-3.1.7%2B1.21.11-sources.jar: io/github/axolotlclient/util/options/rounded/ForceableBooleanWidget.java <==
/*
 * Copyright © 2024 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.util.options.rounded;

import io.github.axolotlclient.AxolotlClientConfig.impl.ui.rounded.widgets.PillBooleanWidget;
import io.github.axolotlclient.util.options.ForceableBooleanOption;
import net.minecraft.class_11907;
import net.minecraft.class_332;

@SuppressWarnings("unused")
public class ForceableBooleanWidget extends PillBooleanWidget {
	private final ForceableBooleanOption option;

	public ForceableBooleanWidget(int x, int y, int width, int height, ForceableBooleanOption option) {
		super(x, y, width, height, option);
		this.option = option;
	}

	@Override
	public void method_75752(class_332 graphics, int mouseX, int mouseY, float delta) {
		this.field_22763 = !option.isForceOff();
		super.method_75752(graphics, mouseX, mouseY, delta);
	}

	@Override
	public void method_25306(class_11907 mods) {
		if (!option.isForceOff()) {
			super.method_25306(mods);
		}
	}
}
